# Codebase Overview

## Repository structure

Within the Aviary repository and package, the codebase is structured as follows:

- `docs` contains the doc files for Aviary
- `examples` contains example code for using Aviary, including external subsystem examples
- `interface` is where most code that users interact with is located
- `mission` contains OpenMDAO components and groups for modeling the aircraft mission
- `models` contains aircraft and propulsion models for use in Aviary examples and tests
- `subsystems` is where the aerodynamic, propulsion, mass, and geometry core subsystems are located
- `utils` contains utility functions for use in Aviary code, examples, and tests
- `validation_cases` contains validation cases for testing and benchmarking Aviary
- `visualization` is where the Aviary dashboard is located
